use strict;
use warnings;
package App::Cronjob;
our $VERSION = '1.000';

# ABSTRACT: wrap up programs to be run as cron jobs


1;

__END__

=pod

=head1 NAME

App::Cronjob - wrap up programs to be run as cron jobs

=head1 VERSION

version 1.000

=head1 SEE INSTEAD

The only useful thing in this distribution, for now, is the L<cronjob|cronjob>
program.

=head1 AUTHOR

  Ricardo Signes <rjbs@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2009 by Ricardo Signes.

This is free software; you can redistribute it and/or modify it under
the same terms as perl itself.

=cut 


